package com.trade.admin.customer.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.trade.admin.customer.domain.CustomerReferralCode;
// import com.trade.admin.customer.domain.SearchCustomerReferralCode;
import com.trade.admin.customer.domain.SearchCustomerReferralCode;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * @description: 客户推荐码
 * @Author: wanglang
 * @Date: 2024/5/30
 * @Version: 1.0
 */
@Mapper
public interface CustomerReferralCodeMapper extends BaseMapper<CustomerReferralCode> {

    /**
     * 查询渠道邀请码配置信息
     *
     * @param referralCodesearch 渠道邀请码配置查询类
     * @return List<CustomerReferralCode> 查询渠道邀请码配置信息集合
     */
    List<CustomerReferralCode> findBySearch(SearchCustomerReferralCode referralCodesearch);

    /**
     * 新增渠道邀请码配置信息
     *
     * @param cod 渠道邀请码配置信息对象
     */
    void add(CustomerReferralCode cod);

    /**
     * 根据ID查询
     *
     * @param id 主键ID
     * @return CustomerReferralCode 渠道邀请码配置信息对象
     */
    CustomerReferralCode get(Long id);

    /**
     * 修改状态（禁用、启用）
     *
     * @param code 渠道邀请码配置信息对象
     * @return int
     */
    int updateStatus(CustomerReferralCode code);

    /**
     * 修改
     *
     * @param code 渠道邀请码配置信息对象
     * @return int
     */
    int update(CustomerReferralCode code);

    /**
     * 一个用户：仅存在一个推荐码
     *
     * @param userId
     * @return CustomerReferralCode
     */
    CustomerReferralCode getByUserId(Long userId);

    /**
     * 整个模块中：推荐码唯一
     *
     * @param referralCode
     * @return CustomerReferralCode
     */
    CustomerReferralCode getByReferralCode(String referralCode);

    /**
     * 整个模块中：唯一
     *
     * @param urlSuffix
     * @return CustomerReferralCode
     */
    CustomerReferralCode getByReferralUrlSuffix(String urlSuffix);

    /**
     * 历史数据处理：查询出所有没有生成二维码的数据
     *
     * @return List<CustomerReferralCode>
     */
    List<CustomerReferralCode> findNullFileId();

    /**
     * 设置二维码附件的ID
     *
     * @param fileId 二维码附件的ID
     * @param id 推荐码主键ID
     * @return int
     */
    int updateFileId(@Param("fileId") Long fileId, @Param("id") Long id);

    /**
     * 删除推荐码
     *
     * @param id 主键
     * @return int
     */
    int delete(@Param("id") Long id);

    CustomerReferralCode getByUserIdAndRoleName(@Param("userId") Long userId, @Param("roleName") String roleName);
}
