package com.trade.admin.system.controller;

import com.google.code.kaptcha.Producer;

import com.trade.admin.system.service.ISysConfigService;
import com.trade.common.config.TradeConfig;
import com.trade.common.constant.CacheConstants;
import com.trade.common.constant.Constants;
import com.trade.common.core.domain.ResponseResult;
import com.trade.common.redis.RedisCache;
import com.trade.common.utils.sign.Base64;
import com.trade.common.utils.uuid.IdUtils;

import org.springframework.util.FastByteArrayOutputStream;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.imageio.ImageIO;
import javax.servlet.http.HttpServletResponse;
import java.awt.image.BufferedImage;
import java.io.IOException;
import java.util.HashMap;
import java.util.Map;
import java.util.concurrent.TimeUnit;

/**
 * @description: 验证码
 * @Author: wanglang
 * @Date: 2024/5/20
 * @Version: 1.0
 */
@RestController
public class CaptchaController {

    @Resource
    private TradeConfig tradeConfig;
    @Resource
    private ISysConfigService configService;
    @Resource
    private RedisCache redisCache;
    @Resource(name = "captchaProducer")
    private Producer captchaProducer;
    @Resource(name = "captchaProducerMath")
    private Producer captchaProducerMath;

    /**
     * 生成验证码
     */
    @GetMapping("/captchaImage")
    public ResponseResult<Map<String, Object>> getCode(HttpServletResponse response) throws IOException {
        Map<String, Object> map = new HashMap<>();
        boolean captchaEnabled = configService.selectCaptchaEnabled();
        map.put("captchaEnabled", captchaEnabled);
        if (!captchaEnabled) {
            return ResponseResult.success(map);
        }
        // 保存验证码信息
        String uuid = IdUtils.simpleUUID();
        String verifyKey = CacheConstants.CAPTCHA_CODE_KEY + uuid;
        String capStr = null;
        String code = null;
        BufferedImage image = null;
        // 生成验证码
        String captchaType = tradeConfig.getCaptchaType();
        if ("math".equals(captchaType)) {
            String capText = captchaProducerMath.createText();
            capStr = capText.substring(0, capText.lastIndexOf("@"));
            code = capText.substring(capText.lastIndexOf("@") + 1);
            image = captchaProducerMath.createImage(capStr);
        } else if ("char".equals(captchaType)) {
            capStr = code = captchaProducer.createText();
            image = captchaProducer.createImage(capStr);
        }
        redisCache.setCacheObject(verifyKey, code, Constants.CAPTCHA_EXPIRATION, TimeUnit.MINUTES);
        // 转换流信息写出
        FastByteArrayOutputStream os = new FastByteArrayOutputStream();
        try {
            ImageIO.write(image, "jpg", os);
        } catch (IOException e) {
            return ResponseResult.error(e.getMessage());
        }
        map.put("uuid", uuid);
        map.put("img", Base64.encode(os.toByteArray()));
        return ResponseResult.success(map);
    }
}
