package com.trade.admin.system.mapper;

import java.util.List;

import com.trade.admin.system.domain.SysUserRole;
import org.apache.ibatis.annotations.Param;

/**
 * 用户与角色关联表 数据层
 */
public interface SysUserRoleMapper {

    /**
     * 通过用户ID删除用户和角色关联
     * 
     * @param userId 用户ID
     * @return 结果
     */
    int deleteUserRoleByUserId(Long userId);

    /**
     * 批量删除用户和角色关联
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    int deleteUserRole(Long[] ids);

    /**
     * 通过角色ID查询角色使用数量
     * 
     * @param roleId 角色ID
     * @return 结果
     */
    int countUserRoleByRoleId(Long roleId);

    /**
     * 批量新增用户角色信息
     * 
     * @param userRoleList 用户角色列表
     * @return 结果
     */
    int batchUserRole(List<SysUserRole> userRoleList);

    /**
     * 删除用户和角色关联信息
     * 
     * @param userRole 用户和角色关联信息
     * @return 结果
     */
    int deleteUserRoleInfo(SysUserRole userRole);

    /**
     * 批量取消授权用户角色
     * 
     * @param roleId 角色ID
     * @param userIds 需要删除的用户数据ID
     * @return 结果
     */
    int deleteUserRoleInfos(@Param("roleId") Long roleId, @Param("userIds") Long[] userIds);

    /**
     * 查询用户角色列表
     * 
     * @param userId 用户id
     * @return 角色id
     */
    List<Long> selectRoleIdByUserId(@Param("userId") Long userId);

    /**
     * 查询用户角色列表
     * 
     * @param roleId 角色id
     * @return 用户id
     */
    List<Long> selectUserIdByRoleId(@Param("roleId") Long roleId);

    /**
     * 查询用户角色关联
     * 
     * @param userId 用户id
     * @param roleId 角色id
     * @return
     */
    SysUserRole selectByUserRole(@Param("userId") Long userId, @Param("roleId") Long roleId);
}
