package com.trade.admin.system.security.handle;

import com.alibaba.fastjson2.JSON;
import com.trade.common.constant.Constants;
import com.trade.admin.manager.AsyncManager;
import com.trade.admin.manager.factory.AsyncFactory;
import com.trade.admin.system.service.ITokenService;
import com.trade.common.core.domain.ResponseResult;
import com.trade.common.utils.ServletUtils;
import com.trade.common.utils.StringUtils;
import com.trade.admin.system.domain.model.LoginUser;
import org.springframework.security.core.Authentication;
import org.springframework.security.web.authentication.logout.LogoutSuccessHandler;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;

/**
 * @description: 自定义退出处理类 返回成功
 * @Author: wanglang
 * @Date: 2023/7/19 11:35
 * @Version: 1.0
 */
@Component
public class LogoutSuccessHandlerImpl implements LogoutSuccessHandler {

    @Resource
    private ITokenService tokenService;

    /**
     * 退出处理
     *
     * @return
     */
    @Override
    public void onLogoutSuccess(HttpServletRequest request, HttpServletResponse response, Authentication authentication)
            throws IOException, ServletException {
        LoginUser loginUser = tokenService.getLoginUser(request);
        if (StringUtils.isNotNull(loginUser)) {
            String userName = loginUser.getUsername();
            // 删除用户缓存记录
            tokenService.delLoginUser(loginUser.getToken());
            // 记录用户退出日志
            AsyncManager.me().execute(AsyncFactory.recordLogininfor(userName, Constants.LOGOUT, "退出成功"));
        }
        ServletUtils.renderString(response, JSON.toJSONString(ResponseResult.success("退出成功")));
    }
}
