package com.trade.admin.system.service.impl;

import com.trade.admin.system.service.ISysRegisterService;
import com.trade.admin.system.domain.entity.SysUser;
import com.trade.admin.system.domain.model.RegisterBody;
import com.trade.admin.system.service.ISysConfigService;
import com.trade.admin.system.service.ISysUserService;
import com.trade.common.constant.CacheConstants;
import com.trade.common.constant.Constants;
import com.trade.common.constant.UserConstants;
import com.trade.common.exception.UserException;
import com.trade.common.redis.RedisCache;
import com.trade.common.security.EncryptUtils;
import com.trade.common.utils.MessageUtils;
import com.trade.common.utils.StringUtils;
import com.trade.admin.manager.AsyncManager;
import com.trade.admin.manager.factory.AsyncFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * @description:
 * @Author: wanglang
 * @Date: 2023/7/27 11:23
 * @Version: 1.0
 */
@Service
public class SysRegisterServiceImpl implements ISysRegisterService {

    @Autowired
    private ISysUserService userService;
    @Autowired
    private ISysConfigService configService;
    @Autowired
    private RedisCache redisCache;

    @Override
    public String register(RegisterBody registerBody) {
        String msg = "";
        String username = registerBody.getUsername();
        String password = registerBody.getPassword();
        SysUser sysUser = new SysUser();
        sysUser.setUserName(username);
        // 验证码开关
        boolean captchaEnabled = configService.selectCaptchaEnabled();
        if (captchaEnabled) {
            validateCaptcha(username, registerBody.getCode(), registerBody.getUuid());
        }
        if (StringUtils.isEmpty(username)) {
            msg = "用户名不能为空";
        } else if (StringUtils.isEmpty(password)) {
            msg = "用户密码不能为空";
        } else if (username.length() < UserConstants.USERNAME_MIN_LENGTH
                || username.length() > UserConstants.USERNAME_MAX_LENGTH) {
                    msg = "账户长度必须在2到20个字符之间";
                } else
            if (password.length() < UserConstants.PASSWORD_MIN_LENGTH
                    || password.length() > UserConstants.PASSWORD_MAX_LENGTH) {
                        msg = "密码长度必须在5到20个字符之间";
                    } else
                if (!userService.checkUserNameUnique(sysUser)) {
                    msg = "保存用户'" + username + "'失败，注册账号已存在";
                } else {
                    sysUser.setNickName(username);
                    sysUser.setPassword(EncryptUtils.encryptPassword(password));
                    boolean regFlag = userService.registerUser(sysUser);
                    if (!regFlag) {
                        msg = "注册失败,请联系系统管理人员";
                    } else {
                        AsyncManager.me().execute(AsyncFactory.recordLogininfor(username, Constants.REGISTER,
                                MessageUtils.message("user.register.success")));
                    }
                }
        return msg;
    }

    /**
     * 校验验证码
     *
     * @param username 用户名
     * @param code 验证码
     * @param uuid 唯一标识
     * @return 结果
     */
    public void validateCaptcha(String username, String code, String uuid) {
        String verifyKey = CacheConstants.CAPTCHA_CODE_KEY + StringUtils.nvl(uuid, "");
        String captcha = redisCache.getCacheObject(verifyKey);
        redisCache.deleteObject(verifyKey);
        if (captcha == null) {
            throw new UserException("user.jcaptcha.expire", null);
        }
        if (!code.equalsIgnoreCase(captcha)) {
            throw new UserException("user.jcaptcha.error", null);
        }
    }
}
