-- ----------------------------
-- 1、部门表
-- ----------------------------
drop table if exists sys_dept;
create table sys_dept
(
    id      bigint(20) not null auto_increment comment '部门id',
    parent_id    bigint(20) default 0 comment '父部门id',
    ancestors    varchar(50) default '' comment '祖级列表',
    dept_name    varchar(30) default '' comment '部门名称',
    order_num    int(4) default 0 comment '显示顺序',
    leader       varchar(20) default null comment '负责人',
    phone        varchar(11) default null comment '联系电话',
    email        varchar(50) default null comment '邮箱',
    status       char(1)     default '0' comment '部门状态（0正常 1停用）',
    del_flag     char(1)     default '0' comment '删除标志（0代表存在 2代表删除）',
    create_by    varchar(64) default '' comment '创建者',
    update_by    varchar(64) default '' comment '更新者',
    gmt_create   TIMESTAMP   DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    gmt_modified TIMESTAMP   DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    primary key (id)
) ENGINE = InnoDB
  DEFAULT CHARACTER SET utf8mb4
  COLLATE utf8mb4_general_ci comment = '部门表';

insert into sys_dept values(100,  0,   '0',   '长安银科资产管理有限公司',   0, 'admin', '15888888888', 'admin@changan-inkasso.com', '0', '0', 'admin', '', sysdate(), sysdate());

-- ----------------------------
-- 2、用户信息表
-- ----------------------------
drop table if exists sys_user;
create table sys_user
(
    id      bigint(20) not null auto_increment comment '用户ID',
    dept_id      bigint(20) default null comment '部门ID',
    user_name    varchar(30) not null comment '用户账号',
    nick_name    varchar(30) not null comment '用户昵称',
    user_type    varchar(2)   default '00' comment '用户类型（00系统用户）',
    email        varchar(50)  default '' comment '用户邮箱',
    phonenumber  varchar(11)  default '' comment '手机号码',
    sex          char(1)      default '0' comment '用户性别（0男 1女 2未知）',
    avatar       varchar(100) default '' comment '头像地址',
    password     varchar(100) default '' comment '密码',
    status       char(1)      default '0' comment '帐号状态（0正常 1停用）',
    del_flag     char(1)      default '0' comment '删除标志（0代表存在 2代表删除）',
    login_ip     varchar(128) default '' comment '最后登录IP',
    login_date   datetime comment '最后登录时间',
    create_by    varchar(64)  default '' comment '创建者',
    update_by    varchar(64)  default '' comment '更新者',
    remark       varchar(500) default null comment '备注',
    gmt_create   TIMESTAMP    DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    gmt_modified TIMESTAMP    DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    primary key (id)
)ENGINE = InnoDB
  DEFAULT CHARACTER SET utf8mb4
  COLLATE utf8mb4_general_ci comment = '用户信息表';

-- ----------------------------
-- 初始化-用户信息表数据
-- ----------------------------
insert into sys_user values(1,  103, 'admin', '长安银科', '00', 'admin@changan-inkasso.com', '18888888888', '1', '', '$2a$10$7JB720yubVSZvUI0rEqK/.VqGOZTH.ulu33dHOiBE8ByOhJIrdAu2', '0', '0', '127.0.0.1', sysdate(), 'admin', '', '管理员', sysdate(), sysdate());
-- ----------------------------
-- 3、岗位信息表
-- ----------------------------
drop table if exists sys_post;
create table sys_post
(
    id      bigint(20) not null auto_increment comment '岗位ID',
    post_code    varchar(64) not null comment '岗位编码',
    post_name    varchar(50) not null comment '岗位名称',
    post_sort    int(4) not null comment '显示顺序',
    status       char(1)     not null comment '状态（0正常 1停用）',
    create_by    varchar(64)  default '' comment '创建者',
    update_by    varchar(64)  default '' comment '更新者',
    remark       varchar(500) default null comment '备注',
    gmt_create   TIMESTAMP    DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    gmt_modified TIMESTAMP    DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    primary key (id)
) ENGINE = InnoDB
  DEFAULT CHARACTER SET utf8mb4
  COLLATE utf8mb4_general_ci comment = '岗位信息表';

-- 初始化-岗位信息表数据
-- ----------------------------
insert into sys_post values(1, 'ceo',  '董事长',    1, '0', 'admin',  '', null, sysdate(), sysdate());
insert into sys_post values(2, 'se',   '项目经理',  2, '0', 'admin', '', null, sysdate(), sysdate());
insert into sys_post values(3, 'hr',   '人力资源',  3, '0', 'admin',  '', null, sysdate(), sysdate());
insert into sys_post values(4, 'user', '普通员工',  4, '0', 'admin', '', null, sysdate(), sysdate());
-- ----------------------------
-- 4、角色信息表
-- ----------------------------
drop table if exists sys_role;
create table sys_role
(
    id             bigint(20) not null auto_increment comment '角色ID',
    role_name           varchar(30)  not null comment '角色名称',
    role_key            varchar(100) not null comment '角色权限字符串',
    role_sort           int(4) not null comment '显示顺序',
    data_scope          char(1)      default '1' comment '数据范围（1：全部数据权限 2：自定数据权限 3：本部门数据权限 4：本部门及以下数据权限）',
    menu_check_strictly tinyint(1) default 1 comment '菜单树选择项是否关联显示',
    dept_check_strictly tinyint(1) default 1 comment '部门树选择项是否关联显示',
    status              char(1)      not null comment '角色状态（0正常 1停用）',
    del_flag            char(1)      default '0' comment '删除标志（0代表存在 2代表删除）',
    create_by           varchar(64)  default '' comment '创建者',
    update_by           varchar(64)  default '' comment '更新者',
    remark              varchar(500) default null comment '备注',
    gmt_create          TIMESTAMP    DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    gmt_modified        TIMESTAMP    DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    primary key (id)
) ENGINE = InnoDB
  DEFAULT CHARACTER SET utf8mb4
  COLLATE utf8mb4_general_ci comment = '角色信息表';

insert into sys_role values(1, '超级管理员',  'admin',  1, 1, 1, 1, '0', '0', 'admin', '', '超级管理员', sysdate(), sysdate());

-- ----------------------------
-- 5、菜单权限表
-- ----------------------------
drop table if exists sys_menu;
create table sys_menu
(
    id      bigint(20) not null auto_increment comment '菜单ID',
    menu_name    varchar(50) not null comment '菜单名称',
    parent_id    bigint(20) default 0 comment '父菜单ID',
    order_num    int(4) default 0 comment '显示顺序',
    path         varchar(200) default '' comment '路由地址',
    component    varchar(255) default null comment '组件路径',
    query        varchar(255) default null comment '路由参数',
    is_frame     int(1) default 1 comment '是否为外链（0是 1否）',
    is_cache     int(1) default 0 comment '是否缓存（0缓存 1不缓存）',
    menu_type    char(1)      default '' comment '菜单类型（M目录 C菜单 F按钮）',
    visible      char(1)      default 0 comment '菜单状态（0显示 1隐藏）',
    status       char(1)      default 0 comment '菜单状态（0正常 1停用）',
    perms        varchar(100) default null comment '权限标识',
    icon         varchar(100) default '#' comment '菜单图标',
    create_by    varchar(64)  default '' comment '创建者',
    update_by    varchar(64)  default '' comment '更新者',
    remark       varchar(500) default '' comment '备注',
    gmt_create   TIMESTAMP    DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    gmt_modified TIMESTAMP    DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    primary key (id)
) ENGINE = InnoDB
  DEFAULT CHARACTER SET utf8mb4
  COLLATE utf8mb4_general_ci comment = '菜单权限表';

-- ----------------------------
-- 初始化-菜单信息表数据
-- ----------------------------
-- 一级菜单
insert into sys_menu values('1', '系统管理', '0', '1', 'system',        null, '', 1, 0, 'M', '0', '0', '', 'system',   'admin', '', '系统管理目录', sysdate(), sysdate());
insert into sys_menu values('2', '系统监控', '0', '2', 'monitor',       null, '', 1, 0, 'M', '0', '0', '', 'monitor',  'admin',  '', '系统监控目录', sysdate(), sysdate());

-- 二级菜单
insert into sys_menu values('100',  '用户管理', '1',   '1', 'user',       'system/user/index',        '', 1, 0, 'C', '0', '0', 'system:user:list',        'user',          'admin',  '',  '用户管理菜单', sysdate(),sysdate());
insert into sys_menu values('101',  '角色管理', '1',   '2', 'role',       'system/role/index',        '', 1, 0, 'C', '0', '0', 'system:role:list',        'peoples',       'admin',  '', '角色管理菜单', sysdate(),sysdate());
insert into sys_menu values('102',  '菜单管理', '1',   '3', 'menu',       'system/menu/index',        '', 1, 0, 'C', '0', '0', 'system:menu:list',        'tree-table',    'admin',  '', '菜单管理菜单', sysdate(),sysdate());
insert into sys_menu values('103',  '部门管理', '1',   '4', 'dept',       'system/dept/index',        '', 1, 0, 'C', '0', '0', 'system:dept:list',        'tree',          'admin', '', '部门管理菜单', sysdate(),sysdate());
insert into sys_menu values('104',  '岗位管理', '1',   '5', 'post',       'system/post/index',        '', 1, 0, 'C', '0', '0', 'system:post:list',        'post',          'admin', '', '岗位管理菜单', sysdate(),sysdate());
insert into sys_menu values('105',  '字典管理', '1',   '6', 'dict',       'system/dict/index',        '', 1, 0, 'C', '0', '0', 'system:dict:list',        'dict',          'admin', '', '字典管理菜单', sysdate(),sysdate());
insert into sys_menu values('106',  '参数设置', '1',   '7', 'config',     'system/config/index',      '', 1, 0, 'C', '0', '0', 'system:config:list',      'edit',          'admin', '', '参数设置菜单', sysdate(),sysdate());
insert into sys_menu values('107',  '通知公告', '1',   '8', 'notice',     'system/notice/index',      '', 1, 0, 'C', '0', '0', 'system:notice:list',      'message',       'admin',  '', '通知公告菜单', sysdate(),sysdate());
insert into sys_menu values('108',  '日志管理', '1',   '9', 'log',        '',                         '', 1, 0, 'M', '0', '0', '',                        'log',           'admin',  '', '日志管理菜单', sysdate(),sysdate());
insert into sys_menu values('109',  '在线用户', '2',   '1', 'online',     'monitor/online/index',     '', 1, 0, 'C', '0', '0', 'monitor:online:list',     'online',        'admin', '', '在线用户菜单', sysdate(),sysdate());
insert into sys_menu values('110',  '服务监控', '2',   '4', 'server',     'monitor/server/index',     '', 1, 0, 'C', '0', '0', 'monitor:server:list',     'server',        'admin', '', '服务监控菜单', sysdate(),sysdate());

-- 三级菜单
insert into sys_menu values('500',  '操作日志', '108', '1', 'operlog',    'monitor/operlog/index',    '', 1, 0, 'C', '0', '0', 'monitor:operlog:list',    'form',          'admin',  '', '操作日志菜单', sysdate(),sysdate());
insert into sys_menu values('501',  '登录日志', '108', '2', 'logininfor', 'monitor/logininfor/index', '', 1, 0, 'C', '0', '0', 'monitor:logininfor:list', 'logininfor',    'admin', '', '登录日志菜单', sysdate(),sysdate());
-- 用户管理按钮
insert into sys_menu values('1000', '用户查询', '100', '1',  '', '', '', 1, 0, 'F', '0', '0', 'system:user:query',          '#', 'admin',  '', '', sysdate(),sysdate());
insert into sys_menu values('1001', '用户新增', '100', '2',  '', '', '', 1, 0, 'F', '0', '0', 'system:user:add',            '#', 'admin', '', '', sysdate(),sysdate());
insert into sys_menu values('1002', '用户修改', '100', '3',  '', '', '', 1, 0, 'F', '0', '0', 'system:user:edit',           '#', 'admin', '', '', sysdate(),sysdate());
insert into sys_menu values('1003', '用户删除', '100', '4',  '', '', '', 1, 0, 'F', '0', '0', 'system:user:remove',         '#', 'admin', '', '', sysdate(),sysdate());
insert into sys_menu values('1004', '用户导出', '100', '5',  '', '', '', 1, 0, 'F', '0', '0', 'system:user:export',         '#', 'admin', '', '', sysdate(),sysdate());
insert into sys_menu values('1005', '用户导入', '100', '6',  '', '', '', 1, 0, 'F', '0', '0', 'system:user:import',         '#', 'admin', '', '', sysdate(),sysdate());
insert into sys_menu values('1006', '重置密码', '100', '7',  '', '', '', 1, 0, 'F', '0', '0', 'system:user:resetPwd',       '#', 'admin', '', '', sysdate(),sysdate());
-- 角色管理按钮
insert into sys_menu values('1007', '角色查询', '101', '1',  '', '', '', 1, 0, 'F', '0', '0', 'system:role:query',          '#', 'admin', '', '', sysdate(),sysdate());
insert into sys_menu values('1008', '角色新增', '101', '2',  '', '', '', 1, 0, 'F', '0', '0', 'system:role:add',            '#', 'admin',  '', '', sysdate(),sysdate());
insert into sys_menu values('1009', '角色修改', '101', '3',  '', '', '', 1, 0, 'F', '0', '0', 'system:role:edit',           '#', 'admin', '', '', sysdate(),sysdate());
insert into sys_menu values('1010', '角色删除', '101', '4',  '', '', '', 1, 0, 'F', '0', '0', 'system:role:remove',         '#', 'admin', '', '', sysdate(),sysdate());
insert into sys_menu values('1011', '角色导出', '101', '5',  '', '', '', 1, 0, 'F', '0', '0', 'system:role:export',         '#', 'admin', '', '', sysdate(),sysdate());
-- 菜单管理按钮
insert into sys_menu values('1012', '菜单查询', '102', '1',  '', '', '', 1, 0, 'F', '0', '0', 'system:menu:query',          '#', 'admin',  '', '', sysdate(),sysdate());
insert into sys_menu values('1013', '菜单新增', '102', '2',  '', '', '', 1, 0, 'F', '0', '0', 'system:menu:add',            '#', 'admin',  '', '', sysdate(),sysdate());
insert into sys_menu values('1014', '菜单修改', '102', '3',  '', '', '', 1, 0, 'F', '0', '0', 'system:menu:edit',           '#', 'admin',  '', '', sysdate(),sysdate());
insert into sys_menu values('1015', '菜单删除', '102', '4',  '', '', '', 1, 0, 'F', '0', '0', 'system:menu:remove',         '#', 'admin',  '', '', sysdate(),sysdate());
-- 部门管理按钮
insert into sys_menu values('1016', '部门查询', '103', '1',  '', '', '', 1, 0, 'F', '0', '0', 'system:dept:query',          '#', 'admin',  '', '', sysdate(),sysdate());
insert into sys_menu values('1017', '部门新增', '103', '2',  '', '', '', 1, 0, 'F', '0', '0', 'system:dept:add',            '#', 'admin',  '', '', sysdate(),sysdate());
insert into sys_menu values('1018', '部门修改', '103', '3',  '', '', '', 1, 0, 'F', '0', '0', 'system:dept:edit',           '#', 'admin',  '', '', sysdate(),sysdate());
insert into sys_menu values('1019', '部门删除', '103', '4',  '', '', '', 1, 0, 'F', '0', '0', 'system:dept:remove',         '#', 'admin',  '', '', sysdate(),sysdate());
-- 岗位管理按钮
insert into sys_menu values('1020', '岗位查询', '104', '1',  '', '', '', 1, 0, 'F', '0', '0', 'system:post:query',          '#', 'admin',  '', '', sysdate(),sysdate());
insert into sys_menu values('1021', '岗位新增', '104', '2',  '', '', '', 1, 0, 'F', '0', '0', 'system:post:add',            '#', 'admin',  '', '', sysdate(),sysdate());
insert into sys_menu values('1022', '岗位修改', '104', '3',  '', '', '', 1, 0, 'F', '0', '0', 'system:post:edit',           '#', 'admin',  '', '', sysdate(),sysdate());
insert into sys_menu values('1023', '岗位删除', '104', '4',  '', '', '', 1, 0, 'F', '0', '0', 'system:post:remove',         '#', 'admin',  '', '', sysdate(),sysdate());
insert into sys_menu values('1024', '岗位导出', '104', '5',  '', '', '', 1, 0, 'F', '0', '0', 'system:post:export',         '#', 'admin',  '', '', sysdate(),sysdate());
-- 字典管理按钮
insert into sys_menu values('1025', '字典查询', '105', '1', '#', '', '', 1, 0, 'F', '0', '0', 'system:dict:query',          '#', 'admin',  '', '', sysdate(),sysdate());
insert into sys_menu values('1026', '字典新增', '105', '2', '#', '', '', 1, 0, 'F', '0', '0', 'system:dict:add',            '#', 'admin',  '', '', sysdate(),sysdate());
insert into sys_menu values('1027', '字典修改', '105', '3', '#', '', '', 1, 0, 'F', '0', '0', 'system:dict:edit',           '#', 'admin',  '', '', sysdate(),sysdate());
insert into sys_menu values('1028', '字典删除', '105', '4', '#', '', '', 1, 0, 'F', '0', '0', 'system:dict:remove',         '#', 'admin',  '', '', sysdate(),sysdate());
insert into sys_menu values('1029', '字典导出', '105', '5', '#', '', '', 1, 0, 'F', '0', '0', 'system:dict:export',         '#', 'admin',  '', '', sysdate(),sysdate());
-- 参数设置按钮
insert into sys_menu values('1030', '参数查询', '106', '1', '#', '', '', 1, 0, 'F', '0', '0', 'system:config:query',        '#', 'admin',  '', '', sysdate(),sysdate());
insert into sys_menu values('1031', '参数新增', '106', '2', '#', '', '', 1, 0, 'F', '0', '0', 'system:config:add',          '#', 'admin',  '', '', sysdate(),sysdate());
insert into sys_menu values('1032', '参数修改', '106', '3', '#', '', '', 1, 0, 'F', '0', '0', 'system:config:edit',         '#', 'admin',  '', '', sysdate(),sysdate());
insert into sys_menu values('1033', '参数删除', '106', '4', '#', '', '', 1, 0, 'F', '0', '0', 'system:config:remove',       '#', 'admin',  '', '', sysdate(),sysdate());
insert into sys_menu values('1034', '参数导出', '106', '5', '#', '', '', 1, 0, 'F', '0', '0', 'system:config:export',       '#', 'admin',  '', '', sysdate(),sysdate());
-- 通知公告按钮
insert into sys_menu values('1035', '公告查询', '107', '1', '#', '', '', 1, 0, 'F', '0', '0', 'system:notice:query',        '#', 'admin',  '', '', sysdate(),sysdate());
insert into sys_menu values('1036', '公告新增', '107', '2', '#', '', '', 1, 0, 'F', '0', '0', 'system:notice:add',          '#', 'admin',  '', '', sysdate(),sysdate());
insert into sys_menu values('1037', '公告修改', '107', '3', '#', '', '', 1, 0, 'F', '0', '0', 'system:notice:edit',         '#', 'admin',  '', '', sysdate(),sysdate());
insert into sys_menu values('1038', '公告删除', '107', '4', '#', '', '', 1, 0, 'F', '0', '0', 'system:notice:remove',       '#', 'admin',  '', '', sysdate(),sysdate());
-- 操作日志按钮
insert into sys_menu values('1039', '操作查询', '500', '1', '#', '', '', 1, 0, 'F', '0', '0', 'monitor:operlog:query',      '#', 'admin',  '', '', sysdate(),sysdate());
insert into sys_menu values('1040', '操作删除', '500', '2', '#', '', '', 1, 0, 'F', '0', '0', 'monitor:operlog:remove',     '#', 'admin',  '', '', sysdate(),sysdate());
insert into sys_menu values('1041', '日志导出', '500', '3', '#', '', '', 1, 0, 'F', '0', '0', 'monitor:operlog:export',     '#', 'admin',  '', '', sysdate(),sysdate());
-- 登录日志按钮
insert into sys_menu values('1042', '登录查询', '501', '1', '#', '', '', 1, 0, 'F', '0', '0', 'monitor:logininfor:query',   '#', 'admin',  '', '', sysdate(),sysdate());
insert into sys_menu values('1043', '登录删除', '501', '2', '#', '', '', 1, 0, 'F', '0', '0', 'monitor:logininfor:remove',  '#', 'admin',  '', '', sysdate(),sysdate());
insert into sys_menu values('1044', '日志导出', '501', '3', '#', '', '', 1, 0, 'F', '0', '0', 'monitor:logininfor:export',  '#', 'admin',  '', '', sysdate(),sysdate());
insert into sys_menu values('1045', '账户解锁', '501', '4', '#', '', '', 1, 0, 'F', '0', '0', 'monitor:logininfor:unlock',  '#', 'admin',  '', '', sysdate(),sysdate());
-- 在线用户按钮
insert into sys_menu values('1046', '在线查询', '109', '1', '#', '', '', 1, 0, 'F', '0', '0', 'monitor:online:query',       '#', 'admin',  '', '', sysdate(),sysdate());
insert into sys_menu values('1047', '批量强退', '109', '2', '#', '', '', 1, 0, 'F', '0', '0', 'monitor:online:batchLogout', '#', 'admin',  '', '', sysdate(),sysdate());
insert into sys_menu values('1048', '单条强退', '109', '3', '#', '', '', 1, 0, 'F', '0', '0', 'monitor:online:forceLogout', '#', 'admin',  '', '', sysdate(),sysdate());


-- ----------------------------
-- 6、用户和角色关联表  用户N-1角色
-- ----------------------------
drop table if exists sys_user_role;
create table sys_user_role
(
    user_id bigint(20) not null comment '用户ID',
    role_id bigint(20) not null comment '角色ID',
    primary key (user_id, role_id)
) ENGINE = InnoDB
  DEFAULT CHARACTER SET utf8mb4
  COLLATE utf8mb4_general_ci comment = '用户和角色关联表';

-- ----------------------------
-- 初始化-用户和角色关联表数据
-- ----------------------------
insert into sys_user_role
values ('1', '1');


-- ----------------------------
-- 7、角色和菜单关联表  角色1-N菜单
-- ----------------------------
drop table if exists sys_role_menu;
create table sys_role_menu
(
    role_id bigint(20) not null comment '角色ID',
    menu_id bigint(20) not null comment '菜单ID',
    primary key (role_id, menu_id)
) ENGINE = InnoDB
  DEFAULT CHARACTER SET utf8mb4
  COLLATE utf8mb4_general_ci comment = '角色和菜单关联表';

-- ----------------------------
-- 8、角色和部门关联表  角色1-N部门
-- ----------------------------
drop table if exists sys_role_dept;
create table sys_role_dept
(
    role_id bigint(20) not null comment '角色ID',
    dept_id bigint(20) not null comment '部门ID',
    primary key (role_id, dept_id)
) ENGINE = InnoDB
  DEFAULT CHARACTER SET utf8mb4
  COLLATE utf8mb4_general_ci comment = '角色和部门关联表';


-- ----------------------------
-- 9、用户与岗位关联表  用户1-N岗位
-- ----------------------------
drop table if exists sys_user_post;
create table sys_user_post
(
    user_id bigint(20) not null comment '用户ID',
    post_id bigint(20) not null comment '岗位ID',
    primary key (user_id, post_id)
) ENGINE = InnoDB
  DEFAULT CHARACTER SET utf8mb4
  COLLATE utf8mb4_general_ci comment = '用户与岗位关联表';

-- ----------------------------
-- 10、操作日志记录
-- ----------------------------
drop table if exists sys_oper_log;
create table sys_oper_log
(
    id        bigint(20) not null auto_increment comment '日志主键',
    title          varchar(50)   default '' comment '模块标题',
    business_type  int(2) default 0 comment '业务类型（0其它 1新增 2修改 3删除）',
    method         varchar(100)  default '' comment '方法名称',
    request_method varchar(10)   default '' comment '请求方式',
    operator_type  int(1) default 0 comment '操作类别（0其它 1后台用户 2手机端用户）',
    oper_name      varchar(50)   default '' comment '操作人员',
    dept_name      varchar(50)   default '' comment '部门名称',
    oper_url       varchar(255)  default '' comment '请求URL',
    oper_ip        varchar(128)  default '' comment '主机地址',
    oper_location  varchar(255)  default '' comment '操作地点',
    oper_param     varchar(2000) default '' comment '请求参数',
    json_result    varchar(2000) default '' comment '返回参数',
    status         int(1) default 0 comment '操作状态（0正常 1异常）',
    error_msg      varchar(2000) default '' comment '错误消息',
    oper_time      datetime comment '操作时间',
    cost_time      bigint(20) default 0 comment '消耗时间',
    gmt_create     TIMESTAMP     DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    gmt_modified   TIMESTAMP     DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    primary key (id),
    key            idx_sys_oper_log_bt (business_type),
    key            idx_sys_oper_log_s (status),
    key            idx_sys_oper_log_ot (oper_time)
) ENGINE = InnoDB
  DEFAULT CHARACTER SET utf8mb4
  COLLATE utf8mb4_general_ci comment = '操作日志记录';


-- ----------------------------
-- 11、字典类型表
-- ----------------------------
drop table if exists sys_dict_type;
create table sys_dict_type
(
    id      bigint(20) not null auto_increment comment '字典主键',
    dict_name    varchar(100) default '' comment '字典名称',
    dict_type    varchar(100) default '' comment '字典类型',
    status       char(1)      default '0' comment '状态（0正常 1停用）',
    create_by    varchar(64)  default '' comment '创建者',
    update_by    varchar(64)  default '' comment '更新者',
    remark       varchar(500) default null comment '备注',
    gmt_create   TIMESTAMP    DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    gmt_modified TIMESTAMP    DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    primary key (id),
    unique (dict_type)
) ENGINE = InnoDB
  DEFAULT CHARACTER SET utf8mb4
  COLLATE utf8mb4_general_ci comment = '字典类型表';

insert into sys_dict_type values(1,  '用户性别', 'sys_user_sex',        '0', 'admin',  '', '用户性别列表', sysdate(),sysdate());
insert into sys_dict_type values(2,  '菜单状态', 'sys_show_hide',       '0', 'admin',  '', '菜单状态列表', sysdate(),sysdate());
insert into sys_dict_type values(3,  '系统开关', 'sys_normal_disable',  '0', 'admin',  '', '系统开关列表', sysdate(),sysdate());
insert into sys_dict_type values(4,  '任务状态', 'sys_job_status',      '0', 'admin',  '', '任务状态列表', sysdate(),sysdate());
insert into sys_dict_type values(5,  '任务分组', 'sys_job_group',       '0', 'admin',  '', '任务分组列表', sysdate(),sysdate());
insert into sys_dict_type values(6,  '系统是否', 'sys_yes_no',          '0', 'admin',  '', '系统是否列表', sysdate(),sysdate());
insert into sys_dict_type values(7,  '通知类型', 'sys_notice_type',     '0', 'admin',  '', '通知类型列表', sysdate(),sysdate());
insert into sys_dict_type values(8,  '通知状态', 'sys_notice_status',   '0', 'admin',  '', '通知状态列表', sysdate(),sysdate());
insert into sys_dict_type values(9,  '操作类型', 'sys_oper_type',       '0', 'admin',  '', '操作类型列表', sysdate(),sysdate());
insert into sys_dict_type values(10, '系统状态', 'sys_common_status',   '0', 'admin',  '', '登录状态列表', sysdate(),sysdate());
-- ----------------------------
-- 12、字典数据表
-- ----------------------------
drop table if exists sys_dict_data;
create table sys_dict_data
(
    id    bigint(20) not null auto_increment comment '字典编码',
    dict_sort    int(4) default 0 comment '字典排序',
    dict_label   varchar(100) default '' comment '字典标签',
    dict_value   varchar(100) default '' comment '字典键值',
    dict_type    varchar(100) default '' comment '字典类型',
    css_class    varchar(100) default null comment '样式属性（其他样式扩展）',
    list_class   varchar(100) default null comment '表格回显样式',
    is_default   char(1)      default 'N' comment '是否默认（Y是 N否）',
    status       char(1)      default '0' comment '状态（0正常 1停用）',
    create_by    varchar(64)  default '' comment '创建者',
    update_by    varchar(64)  default '' comment '更新者',
    remark       varchar(500) default null comment '备注',
    gmt_create   TIMESTAMP    DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    gmt_modified TIMESTAMP    DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    primary key (id)
) ENGINE = InnoDB
  DEFAULT CHARACTER SET utf8mb4
  COLLATE utf8mb4_general_ci comment = '字典数据表';

insert into sys_dict_data values(1,  1,  '男',       '0',       'sys_user_sex',        '',   '',        'Y', '0', 'admin',  '', '性别男', sysdate(),sysdate());
insert into sys_dict_data values(2,  2,  '女',       '1',       'sys_user_sex',        '',   '',        'N', '0', 'admin',  '', '性别女', sysdate(),sysdate());
insert into sys_dict_data values(3,  3,  '未知',     '2',       'sys_user_sex',        '',   '',        'N', '0', 'admin',  '', '性别未知', sysdate(),sysdate());
insert into sys_dict_data values(4,  1,  '显示',     '0',       'sys_show_hide',       '',   'primary', 'Y', '0', 'admin',  '', '显示菜单', sysdate(),sysdate());
insert into sys_dict_data values(5,  2,  '隐藏',     '1',       'sys_show_hide',       '',   'danger',  'N', '0', 'admin',  '', '隐藏菜单', sysdate(),sysdate());
insert into sys_dict_data values(6,  1,  '正常',     '0',       'sys_normal_disable',  '',   'primary', 'Y', '0', 'admin',  '', '正常状态', sysdate(),sysdate());
insert into sys_dict_data values(7,  2,  '停用',     '1',       'sys_normal_disable',  '',   'danger',  'N', '0', 'admin',  '', '停用状态', sysdate(),sysdate());
insert into sys_dict_data values(8,  1,  '正常',     '0',       'sys_job_status',      '',   'primary', 'Y', '0', 'admin',  '', '正常状态', sysdate(),sysdate());
insert into sys_dict_data values(9,  2,  '暂停',     '1',       'sys_job_status',      '',   'danger',  'N', '0', 'admin',  '', '停用状态', sysdate(),sysdate());
insert into sys_dict_data values(10, 1,  '默认',     'DEFAULT', 'sys_job_group',       '',   '',        'Y', '0', 'admin',  '', '默认分组', sysdate(),sysdate());
insert into sys_dict_data values(11, 2,  '系统',     'SYSTEM',  'sys_job_group',       '',   '',        'N', '0', 'admin',  '', '系统分组', sysdate(),sysdate());
insert into sys_dict_data values(12, 1,  '是',       'Y',       'sys_yes_no',          '',   'primary', 'Y', '0', 'admin',  '', '系统默认是', sysdate(),sysdate());
insert into sys_dict_data values(13, 2,  '否',       'N',       'sys_yes_no',          '',   'danger',  'N', '0', 'admin',  '', '系统默认否', sysdate(),sysdate());
insert into sys_dict_data values(14, 1,  '通知',     '1',       'sys_notice_type',     '',   'warning', 'Y', '0', 'admin',  '', '通知', sysdate(),sysdate());
insert into sys_dict_data values(15, 2,  '公告',     '2',       'sys_notice_type',     '',   'success', 'N', '0', 'admin',  '', '公告', sysdate(),sysdate());
insert into sys_dict_data values(16, 1,  '正常',     '0',       'sys_notice_status',   '',   'primary', 'Y', '0', 'admin',  '', '正常状态', sysdate(),sysdate());
insert into sys_dict_data values(17, 2,  '关闭',     '1',       'sys_notice_status',   '',   'danger',  'N', '0', 'admin',  '', '关闭状态', sysdate(),sysdate());
insert into sys_dict_data values(18, 99, '其他',     '0',       'sys_oper_type',       '',   'info',    'N', '0', 'admin',  '', '其他操作', sysdate(),sysdate());
insert into sys_dict_data values(19, 1,  '新增',     '1',       'sys_oper_type',       '',   'info',    'N', '0', 'admin',  '', '新增操作', sysdate(),sysdate());
insert into sys_dict_data values(20, 2,  '修改',     '2',       'sys_oper_type',       '',   'info',    'N', '0', 'admin',  '', '修改操作', sysdate(),sysdate());
insert into sys_dict_data values(21, 3,  '删除',     '3',       'sys_oper_type',       '',   'danger',  'N', '0', 'admin',  '', '删除操作', sysdate(),sysdate());
insert into sys_dict_data values(22, 4,  '授权',     '4',       'sys_oper_type',       '',   'primary', 'N', '0', 'admin',  '', '授权操作', sysdate(),sysdate());
insert into sys_dict_data values(23, 5,  '导出',     '5',       'sys_oper_type',       '',   'warning', 'N', '0', 'admin',  '', '导出操作', sysdate(),sysdate());
insert into sys_dict_data values(24, 6,  '导入',     '6',       'sys_oper_type',       '',   'warning', 'N', '0', 'admin',  '', '导入操作', sysdate(),sysdate());
insert into sys_dict_data values(25, 7,  '强退',     '7',       'sys_oper_type',       '',   'danger',  'N', '0', 'admin',  '', '强退操作', sysdate(),sysdate());
insert into sys_dict_data values(26, 9,  '清空数据', '9',       'sys_oper_type',       '',   'danger',  'N', '0', 'admin',  '', '清空操作', sysdate(),sysdate());
insert into sys_dict_data values(27, 1,  '成功',     '0',       'sys_common_status',   '',   'primary', 'N', '0', 'admin',  '', '正常状态', sysdate(),sysdate());
insert into sys_dict_data values(28, 2,  '失败',     '1',       'sys_common_status',   '',   'danger',  'N', '0', 'admin',  '', '停用状态', sysdate(),sysdate());

-- ----------------------------
-- 13、参数配置表
-- ----------------------------
drop table if exists sys_config;
create table sys_config
(
    id    int(5) not null auto_increment comment '参数主键',
    config_name  varchar(100) default '' comment '参数名称',
    config_key   varchar(100) default '' comment '参数键名',
    config_value varchar(500) default '' comment '参数键值',
    config_type  char(1)      default 'N' comment '系统内置（Y是 N否）',
    create_by    varchar(64)  default '' comment '创建者',
    update_by    varchar(64)  default '' comment '更新者',
    remark       varchar(500) default null comment '备注',
    gmt_create   TIMESTAMP    DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    gmt_modified TIMESTAMP    DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    primary key (id)
) ENGINE = InnoDB
  DEFAULT CHARACTER SET utf8mb4
  COLLATE utf8mb4_general_ci comment = '参数配置表';

insert into sys_config values(1, '主框架页-默认皮肤样式名称',     'sys.index.skinName',            'skin-blue',     'Y', 'admin',  '', '蓝色 skin-blue、绿色 skin-green、紫色 skin-purple、红色 skin-red、黄色 skin-yellow' , sysdate(),sysdate());
insert into sys_config values(2, '用户管理-账号初始密码',         'sys.user.initPassword',         '123456',        'Y', 'admin',  '', '初始化密码 123456' , sysdate(),sysdate());
insert into sys_config values(3, '主框架页-侧边栏主题',           'sys.index.sideTheme',           'theme-dark',    'Y', 'admin',  '', '深色主题theme-dark，浅色主题theme-light' , sysdate(),sysdate());
insert into sys_config values(4, '账号自助-验证码开关',           'sys.account.captchaEnabled',    'true',          'Y', 'admin',  '', '是否开启验证码功能（true开启，false关闭）', sysdate(),sysdate());
insert into sys_config values(5, '账号自助-是否开启用户注册功能', 'sys.account.registerUser',      'false',         'Y', 'admin',  '', '是否开启注册用户功能（true开启，false关闭）', sysdate(),sysdate());
insert into sys_config values(6, '用户登录-黑名单列表',           'sys.login.blackIPList',         '',              'Y', 'admin',  '', '设置登录IP黑名单限制，多个匹配项以;分隔，支持匹配（*通配、网段）', sysdate(),sysdate());


-- ----------------------------
-- 14、系统访问记录
-- ----------------------------
drop table if exists sys_logininfor;
create table sys_logininfor
(
    id        bigint(20) not null auto_increment comment '访问ID',
    user_name      varchar(50)  default '' comment '用户账号',
    ipaddr         varchar(128) default '' comment '登录IP地址',
    login_location varchar(255) default '' comment '登录地点',
    browser        varchar(50)  default '' comment '浏览器类型',
    os             varchar(50)  default '' comment '操作系统',
    status         char(1)      default '0' comment '登录状态（0成功 1失败）',
    msg            varchar(255) default '' comment '提示消息',
    login_time     datetime comment '访问时间',
    gmt_create     TIMESTAMP    DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    gmt_modified   TIMESTAMP    DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    primary key (id),
    key            idx_sys_logininfor_s (status),
    key            idx_sys_logininfor_lt (login_time)
) ENGINE = InnoDB
  DEFAULT CHARACTER SET utf8mb4
  COLLATE utf8mb4_general_ci comment = '系统访问记录';

-- ----------------------------
-- 15、通知公告表
-- ----------------------------
drop table if exists sys_notice;
create table sys_notice
(
    id      int(4) not null auto_increment comment '公告ID',
    notice_title   varchar(50) not null comment '公告标题',
    notice_type    char(1)     not null comment '公告类型（1通知 2公告）',
    notice_content longblob     default null comment '公告内容',
    status         char(1)      default '0' comment '公告状态（0正常 1关闭）',
    create_by      varchar(64)  default '' comment '创建者',
    update_by      varchar(64)  default '' comment '更新者',
    remark         varchar(255) default null comment '备注',
    gmt_create     TIMESTAMP    DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    gmt_modified   TIMESTAMP    DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    primary key (id)
) ENGINE = InnoDB
  DEFAULT CHARACTER SET utf8mb4
  COLLATE utf8mb4_general_ci comment = '通知公告表';
