package com.trade.service.filestorage.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.trade.service.filestorage.entity.TFileStorage;

import java.util.List;

/**
 * <p>
 * 文件存储信息表 服务类
 * </p>
 *
 * @author baomidou
 * @since 2024-04-01
 */
public interface TFileStorageService extends IService<TFileStorage> {

    /**
     * 新增并返回新增对象
     * 
     * @param fileStorage 文件存储对象
     * @return TFileStorage
     */
    TFileStorage add(TFileStorage fileStorage);

    /**
     * 根据文件ID查询文件存储信息
     * 
     * @param fileId 文件存储id
     * @return TFileStorage
     */
    TFileStorage getFileStorageById(Long fileId);

    /**
     * 根据业务编号和业务类型查询文件列表
     * 
     * @param bizNo 业务编号
     * @param bizType 业务类型
     * @return List<TFileStorage>
     */
    List<TFileStorage> getFilesByBizNoAndBizType(String bizNo, String bizType);

    /**
     * 根据业务编号和业务类型 + 文件类型查询文件列表
     *
     * @param bizNo 业务编号
     * @param bizType 业务类型
     * @param fileType 文件类型
     * @return List<TFileStorage>
     */
    List<TFileStorage> getFilesByBizAndFileType(String bizNo, String bizType, String fileType);
}
