package com.trade.service.tradingPlatform.dto;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.trade.common.core.dto.BaseDTO;
import com.trade.common.validate.ValidatorGroup;
import com.trade.service.filestorage.dto.FileAbstractDto;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.util.Date;
import java.util.List;

/**
 * 贸易平台资质
 *
 * @author hlb
 * @since 2024-06-05 17:00:03
 */
public class TradingPlatformQualificationDto extends BaseDTO {

    /**
     * ID
     */
    private Long id;
    /**
     * 贸易平台id
     */
    private Long platformId;
    /**
     * 贸易平台编码
     */
    private String platformCode;
    /**
     * 经营范围是否包含“货物进出口”业务类型，枚举：sys_yes_no
     */
    @NotBlank(message = "经营范围是否包含“货物进出口”业务类型不能为空", groups = {
            ValidatorGroup.Submit.class
    })
    private String hasImportExportScope;
    /**
     * 是否已完成海关进出口货物收发货人登记，枚举：sys_yes_no
     */
    @NotBlank(message = "是否已完成海关进出口货物收发货人登记不能为空", groups = {
            ValidatorGroup.Submit.class
    })
    private String finishedCustomsConsignorRegister;
    /**
     * 是否完成电子口岸入网，枚举：sys_yes_no
     */
    @NotBlank(message = "是否完成电子口岸入网不能为空", groups = {
            ValidatorGroup.Submit.class
    })
    private String finishedEportAccess;
    /**
     * 是否完成外汇管理局外汇收支名录登记，枚举：sys_yes_no
     */
    @NotBlank(message = "是否完成外汇管理局外汇收支名录登记不能为空", groups = {
            ValidatorGroup.Submit.class
    })
    private String finishedForeignExchangeRegister;
    /**
     * 是否完成出口退（免）税资格备案，枚举：sys_yes_no
     */
    @NotBlank(message = "是否完成出口退（免）税资格备案不能为空", groups = {
            ValidatorGroup.Submit.class
    })
    private String finishedTaxRefundRecord;
    /**
     * 是否具备代理出口资质，枚举：sys_yes_no
     */
    @NotBlank(message = "是否具备出口代理资质不能为空", groups = {
            ValidatorGroup.Submit.class
    })
    private String hasExportAgentQualify;
    /**
     * 是否具备一般纳税人资质，枚举：sys_yes_no
     */
    @NotBlank(message = "是否具备一般纳税人资质不能为空", groups = {
            ValidatorGroup.Submit.class
    })
    private String hasGeneralTaxpayerQualify;
    /**
     * 是否具备进出口资质，枚举：sys_yes_no
     */
    @NotBlank(message = "是否具备进出口资质不能为空", groups = {
            ValidatorGroup.Submit.class
    })
    private String hasImportExportQualification;
    /**
     * 经营商品大类，枚举：commodity_major_class
     */
    @NotBlank(message = "经营商品大类不能为空", groups = {
            ValidatorGroup.Submit.class
    })
    private String commodityMajorClass;
    /**
     * 历史出口商品大类，枚举：business_category，列表
     */
    @NotNull(message = "历史出口商品大类不能为空", groups = {
            ValidatorGroup.Submit.class
    })
    private List<String> hisExportCommodityClass;
    /**
     * 特殊商品经营许可
     */
    private FileAbstractDto commoditySpecialQualification;
    /**
     * 备注信息
     */
    private String remark;
    /**
     * 创建者
     */
    private String createBy;
    /**
     * 更新者
     */
    private String updateBy;
    /**
     * 创建时间 yyyy-MM-dd HH:mm:ss
     */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private Date gmtCreate;
    /**
     * 更新时间 yyyy-MM-dd HH:mm:ss
     */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private Date gmtModified;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getPlatformId() {
        return platformId;
    }

    public void setPlatformId(Long platformId) {
        this.platformId = platformId;
    }

    public String getPlatformCode() {
        return platformCode;
    }

    public void setPlatformCode(String platformCode) {
        this.platformCode = platformCode;
    }

    public String getHasImportExportScope() {
        return hasImportExportScope;
    }

    public void setHasImportExportScope(String hasImportExportScope) {
        this.hasImportExportScope = hasImportExportScope;
    }

    public String getFinishedCustomsConsignorRegister() {
        return finishedCustomsConsignorRegister;
    }

    public void setFinishedCustomsConsignorRegister(String finishedCustomsConsignorRegister) {
        this.finishedCustomsConsignorRegister = finishedCustomsConsignorRegister;
    }

    public String getFinishedEportAccess() {
        return finishedEportAccess;
    }

    public void setFinishedEportAccess(String finishedEportAccess) {
        this.finishedEportAccess = finishedEportAccess;
    }

    public String getFinishedForeignExchangeRegister() {
        return finishedForeignExchangeRegister;
    }

    public void setFinishedForeignExchangeRegister(String finishedForeignExchangeRegister) {
        this.finishedForeignExchangeRegister = finishedForeignExchangeRegister;
    }

    public String getFinishedTaxRefundRecord() {
        return finishedTaxRefundRecord;
    }

    public void setFinishedTaxRefundRecord(String finishedTaxRefundRecord) {
        this.finishedTaxRefundRecord = finishedTaxRefundRecord;
    }

    public String getHasExportAgentQualify() {
        return hasExportAgentQualify;
    }

    public void setHasExportAgentQualify(String hasExportAgentQualify) {
        this.hasExportAgentQualify = hasExportAgentQualify;
    }

    public String getHasGeneralTaxpayerQualify() {
        return hasGeneralTaxpayerQualify;
    }

    public void setHasGeneralTaxpayerQualify(String hasGeneralTaxpayerQualify) {
        this.hasGeneralTaxpayerQualify = hasGeneralTaxpayerQualify;
    }

    public String getHasImportExportQualification() {
        return hasImportExportQualification;
    }

    public void setHasImportExportQualification(String hasImportExportQualification) {
        this.hasImportExportQualification = hasImportExportQualification;
    }

    public String getCommodityMajorClass() {
        return commodityMajorClass;
    }

    public void setCommodityMajorClass(String commodityMajorClass) {
        this.commodityMajorClass = commodityMajorClass;
    }

    public List<String> getHisExportCommodityClass() {
        return hisExportCommodityClass;
    }

    public void setHisExportCommodityClass(List<String> hisExportCommodityClass) {
        this.hisExportCommodityClass = hisExportCommodityClass;
    }

    public FileAbstractDto getCommoditySpecialQualification() {
        return commoditySpecialQualification;
    }

    public void setCommoditySpecialQualification(FileAbstractDto commoditySpecialQualification) {
        this.commoditySpecialQualification = commoditySpecialQualification;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public String getCreateBy() {
        return createBy;
    }

    public void setCreateBy(String createBy) {
        this.createBy = createBy;
    }

    public String getUpdateBy() {
        return updateBy;
    }

    public void setUpdateBy(String updateBy) {
        this.updateBy = updateBy;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}
